<?php
namespace Drupal\ixm_components_ui_kit\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class IxmComponentsUiKitSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'ixm_components_ui_kit.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ixm_components_ui_kit_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['enable_dev_kit'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Developer Kit'),
      '#description' => $this->t('Displays example implementations for developers on the UI Kit.'),
      '#default_value' => $config->get('enable_dev_kit'),
    ];

    $theme = \Drupal::config('system.theme')->get('default');
    $theme_path = \Drupal::service('extension.list.theme')->getPath($theme);
    $icons_source_path = $config->get('icons_source_path');
    if (!$icons_source_path) {
      $icons_source_path = '/' . $theme_path . '/assets/icons/';
    }
    $form['icons_source_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Source icons path'),
      '#description' => $this->t('The folder should point to your source (uncompiled) SVG files. <br/>Defaults to: <strong>' . '/' . $theme_path . '/assets/icons/' . '</strong>'),
      '#default_value' => $icons_source_path,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::SETTINGS)
      ->set('enable_dev_kit', $form_state->getValue('enable_dev_kit'))
      ->set('icons_source_path', $form_state->getValue('icons_source_path'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
